==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkStructuredGridConnectivity.java <==
// java wrapper for vtkStructuredGridConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredGridConnectivity extends vtkAbstractGridConnectivity
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_3(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_3(id0); }

  private native int[]  GetWholeExtent_4();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_4(); }

  private native int GetDataDimension_5();
  public int GetDataDimension()
    { return GetDataDimension_5(); }

  private native void SetNumberOfGrids_6(int id0);
  public void SetNumberOfGrids(int id0)
    { SetNumberOfGrids_6(id0); }

  private native void RegisterGrid_7(int id0,int id1[],vtkUnsignedCharArray id2,vtkUnsignedCharArray id3,vtkPointData id4,vtkCellData id5,vtkPoints id6);
  public void RegisterGrid(int id0,int id1[],vtkUnsignedCharArray id2,vtkUnsignedCharArray id3,vtkPointData id4,vtkCellData id5,vtkPoints id6)
    { RegisterGrid_7(id0,id1,id2,id3,id4,id5,id6); }

  private native void GetGridExtent_8(int id0,int id1[]);
  public void GetGridExtent(int id0,int id1[])
    { GetGridExtent_8(id0,id1); }

  private native void SetGhostedGridExtent_9(int id0,int id1[]);
  public void SetGhostedGridExtent(int id0,int id1[])
    { SetGhostedGridExtent_9(id0,id1); }

  private native void GetGhostedGridExtent_10(int id0,int id1[]);
  public void GetGhostedGridExtent(int id0,int id1[])
    { GetGhostedGridExtent_10(id0,id1); }

  private native void ComputeNeighbors_11();
  public void ComputeNeighbors()
    { ComputeNeighbors_11(); }

  private native int GetNumberOfNeighbors_12(int id0);
  public int GetNumberOfNeighbors(int id0)
    { return GetNumberOfNeighbors_12(id0); }

  private native void FillGhostArrays_13(int id0,vtkUnsignedCharArray id1,vtkUnsignedCharArray id2);
  public void FillGhostArrays(int id0,vtkUnsignedCharArray id1,vtkUnsignedCharArray id2)
    { FillGhostArrays_13(id0,id1,id2); }

  private native void CreateGhostLayers_14(int id0);
  public void CreateGhostLayers(int id0)
    { CreateGhostLayers_14(id0); }

  public vtkStructuredGridConnectivity() { super(); }

  public vtkStructuredGridConnectivity(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-13-armv6h.pkg.tar.xz: vtk/vtkStructuredGridConnectivity.java <==
// java wrapper for vtkStructuredGridConnectivity object
//

package vtk;
import vtk.*;

public class vtkStructuredGridConnectivity extends vtkAbstractGridConnectivity
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetWholeExtent_2(int id0,int id1,int id2,int id3,int id4,int id5);
  public void SetWholeExtent(int id0,int id1,int id2,int id3,int id4,int id5)
    { SetWholeExtent_2(id0,id1,id2,id3,id4,id5); }

  private native void SetWholeExtent_3(int id0[]);
  public void SetWholeExtent(int id0[])
    { SetWholeExtent_3(id0); }

  private native int[]  GetWholeExtent_4();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_4(); }

  private native int GetDataDimension_5();
  public int GetDataDimension()
    { return GetDataDimension_5(); }

  private native void SetNumberOfGrids_6(int id0);
  public void SetNumberOfGrids(int id0)
    { SetNumberOfGrids_6(id0); }

  private native void RegisterGrid_7(int id0,int id1[],vtkUnsignedCharArray id2,vtkUnsignedCharArray id3,vtkPointData id4,vtkCellData id5,vtkPoints id6);
  public void RegisterGrid(int id0,int id1[],vtkUnsignedCharArray id2,vtkUnsignedCharArray id3,vtkPointData id4,vtkCellData id5,vtkPoints id6)
    { RegisterGrid_7(id0,id1,id2,id3,id4,id5,id6); }

  private native void GetGridExtent_8(int id0,int id1[]);
  public void GetGridExtent(int id0,int id1[])
    { GetGridExtent_8(id0,id1); }

  private native void SetGhostedGridExtent_9(int id0,int id1[]);
  public void SetGhostedGridExtent(int id0,int id1[])
    { SetGhostedGridExtent_9(id0,id1); }

  private native void GetGhostedGridExtent_10(int id0,int id1[]);
  public void GetGhostedGridExtent(int id0,int id1[])
    { GetGhostedGridExtent_10(id0,id1); }

  private native void ComputeNeighbors_11();
  public void ComputeNeighbors()
    { ComputeNeighbors_11(); }

  private native int GetNumberOfNeighbors_12(int id0);
  public int GetNumberOfNeighbors(int id0)
    { return GetNumberOfNeighbors_12(id0); }

  private native void FillGhostArrays_13(int id0,vtkUnsignedCharArray id1,vtkUnsignedCharArray id2);
  public void FillGhostArrays(int id0,vtkUnsignedCharArray id1,vtkUnsignedCharArray id2)
    { FillGhostArrays_13(id0,id1,id2); }

  private native void CreateGhostLayers_14(int id0);
  public void CreateGhostLayers(int id0)
    { CreateGhostLayers_14(id0); }

  public vtkStructuredGridConnectivity() { super(); }

  public vtkStructuredGridConnectivity(long id) { super(id); }
  public native long   VTKInit();

}
